==> jboss-3.2.6-src.tar.bz2: jboss-3.2.6-src/jaxrpc/src/main/org/apache/axis/handlers/DebugHandler.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.axis.handlers;

import org.apache.axis.AxisFault;
import org.apache.axis.Constants;
import org.apache.axis.Message;
import org.apache.axis.MessageContext;
import org.apache.axis.components.logger.LogFactory;
import org.apache.axis.message.SOAPEnvelopeAxisImpl;
import org.apache.axis.message.SOAPHeaderElementAxisImpl;
import org.apache.axis.utils.Messages;
import org.apache.commons.logging.Log;


/**
 * @author Doug Davis (dug@us.ibm.com)
 */
public class DebugHandler extends BasicHandler
{
   private static Log log =
           LogFactory.getLog(DebugHandler.class.getName());

   public static final String NS_URI_DEBUG = "http://xml.apache.org/axis/debug";

   public void invoke(MessageContext msgContext) throws AxisFault
   {
      log.debug("Enter: DebugHandler::invoke");
      try
      {
         Message msg = msgContext.getRequestMessage();

         SOAPEnvelopeAxisImpl message = (SOAPEnvelopeAxisImpl)msg.getSOAPEnvelope();
         SOAPHeaderElementAxisImpl header = message.
                 getHeaderByName(NS_URI_DEBUG, "Debug");

         if (header != null)
         {
            Integer i = ((Integer)header
                    .getValueAsType(Constants.XSD_INT));
            if (i == null)
               throw new AxisFault(Messages.getMessage("cantConvert03"));

            int debugVal = i.intValue();
            log.debug(Messages.getMessage("debugLevel00", "" + debugVal));
            //Debug.setDebugLevel(debugVal);
            header.setProcessed(true);
         }
      }
      catch (Exception e)
      {
         log.error(Messages.getMessage("exception00"), e);
         throw AxisFault.makeFault(e);
      }
      log.debug("Exit: DebugHandler::invoke");
   }

   public void onFault(MessageContext msgContext)
   {
      log.debug("Enter: DebugHandler::onFault");
      log.debug("Exit: DebugHandler::onFault");
   }

}

;

==> jboss-3.2.7-src.tar.bz2: jboss-3.2.7-src/jaxrpc/src/main/org/apache/axis/handlers/DebugHandler.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.axis.handlers;

import org.apache.axis.AxisFault;
import org.apache.axis.Constants;
import org.apache.axis.Message;
import org.apache.axis.MessageContext;
import org.apache.axis.message.SOAPEnvelopeAxisImpl;
import org.apache.axis.message.SOAPHeaderElementAxisImpl;
import org.apache.axis.utils.Messages;
import org.jboss.logging.Logger;


/**
 * @author Doug Davis (dug@us.ibm.com)
 */
public class DebugHandler extends BasicHandler
{
   private static Logger log = Logger.getLogger(DebugHandler.class.getName());

   public static final String NS_URI_DEBUG = "http://xml.apache.org/axis/debug";

   public void invoke(MessageContext msgContext) throws AxisFault
   {
      log.debug("Enter: DebugHandler::invoke");
      try
      {
         Message msg = msgContext.getRequestMessage();

         SOAPEnvelopeAxisImpl message = (SOAPEnvelopeAxisImpl)msg.getSOAPEnvelope();
         SOAPHeaderElementAxisImpl header = message.
                 getHeaderByName(NS_URI_DEBUG, "Debug");

         if (header != null)
         {
            Integer i = ((Integer)header
                    .getValueAsType(Constants.XSD_INT));
            if (i == null)
               throw new AxisFault(Messages.getMessage("cantConvert03"));

            int debugVal = i.intValue();
            log.debug(Messages.getMessage("debugLevel00", "" + debugVal));
            //Debug.setDebugLevel(debugVal);
            header.setProcessed(true);
         }
      }
      catch (Exception e)
      {
         log.error(Messages.getMessage("exception00"), e);
         throw AxisFault.makeFault(e);
      }
      log.debug("Exit: DebugHandler::invoke");
   }

   public void onFault(MessageContext msgContext)
   {
      log.debug("Enter: DebugHandler::onFault");
      log.debug("Exit: DebugHandler::onFault");
   }

}

;
